#
# spec file for package cosmic-player
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicPlayer
Name:           cosmic-player
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        COSMIC media player
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-player
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  just
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(xkbcommon)

%description
%{summary}.

%prep
%autosetup -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/*/apps/%{appname}.svg
%{_datadir}/metainfo/%{appname}.metainfo.xml

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * i18n - Update portuguese translations
  * Enable tokio/sync and url/serde features
  * Minor translation fixes
  * i18n(ro): Add Romanian translation
  * Update cosmic_player.ftl
  * Update cosmic_player.ftl
  * feat(controls): Hide header bar if no mouse movement
  * fix bug: string
  * i18n(zh-TW): add zh-TW translation
  * fix(args): Eliminate the binary from arguments
  * feat: add help and version flags to argument parser
  * i18n (pt-BR) Update translations
  * i18n(zh-CN): update zh-CN translation
  * Add daemon mode support
  * Accept a list of URLs in desktop file
  * add shell.nix file
  * Playlist with multiple, mixed items
  * Parse multiple URLs via command line
  * Update cosmic_player.ftl (jp)
  * Update cosmic_player.ftl for Japanese
  * i18n(pt): update portuguese translation
  * Create cosmic_player.ftl
  * i18n(it): update italian translation
  * Updating Irish translations since Decemeber 24
  * i18n(sk): Add Slovak translations
  * i18n(de): add German translation
  * Update Hungarian translations
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * Update cosmic_player.ftl PL translation missing metadata
  * i18n(nl) update Dutch translation
  * Update Hungarian translations
  * Update cosmic_player.ftl
  * Open folder passed as command line arg
  * i18n(pt-BR): update translations
  * Update Swedish translation
  * i18n(nl) improve Dutch translation
  * i18n(zh-CN):Update translation of zh-CN
  * Support missing metadata
  * Adjust text color
  * Use bg_component_color as background for audio
  * Show metadata for audio files
  * Update cosmic_player.ftl PL translation
  * Update Hungarian translations
  * Add Hungarian translations
  * Add tree view
  * Add recent media
  * Fix deadlocks when opening files while another file is playing
  * Update cosmic_player.ftl
  * Scale down album art image
  * Show open with button when no media loaded
  * Move seek to second line when condensed
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+2:
  * Improve argument handling
  * Implement MPRIS and album art, fixes #57, fixes #59, part of #56
  * Update cosmic_player.ftl ITA (#50)
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+2:
  * Update dependencies
  * Update cosmic_player.ftl (#36)
  * Revert Cargo.lock to version 3
  * Use just vendor for debian packaging
  * spell check and improve Dutch translation (#33)
  * Improve plugin install logic
  * Update iced_video_player
  * i18n(de): add German translation
  * Create cosmic_player.ftl PL initial translation
  * Added Irish translation
  * update dutch translation
  * update italian translation
  * update french translation
  * update euro spanish translation
  * update japanese translation
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 0.1.0+git20241205.b26005d:
  * Move language selection to bottom bar, implement volume
  * Add file menu, improve naming of subtitles
  * Create cosmic_player.ftl
  * Update iced video player
  * Use prev-master branch of libcosmic
  * i18n (pt-BR) translation update
  * Improve argument handling
  * Fix appstream data
  * Update dependencies
- remove patch ffmpeg-next.patch as it's not required anymore
* Tue Oct  8 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.1.0+git20241008.d614269:
  * rework app to use gstreamer, not ffmpeg
  * update dependencies
  * auto hide controls
  * add fullscreen toggle
  * auto selecting audio and subtitles
- remove patch ffmpeg-7.patch as ffmpeg is not directly a requirement
  anymore
* Thu Aug 29 2024 Richard Rahl <rrahl0@opensuse.org>
- fix Tumbleweed by using ffmpeg-next.patch and ffmpeg-7.patch
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
